@@ -33,6 +33,14 @@ void DayHistory::showInfo(QModelIndex index)
     hiw->show();
 }
 
+void DayHistory::changeEvent(QEvent *event)
+{
+    if(event->type() == QEvent::ActivationChange)
+    {
+        load(currentDate);
+    }
+}
+
 void DayHistory::load(QString date)
 {
     QList <QString> tmp;
