@@ -34,7 +34,8 @@ private:
     QMaemo5ListPickSelector *selectorGroup;
     QStandardItemModel *model;
 
-    QString pic1,pic2;
+    QString pic1,pic2, oldName;
+
 private slots:
     void saveExercise();
     void orientationChanged();
