@@ -13,7 +13,7 @@ WeightDialog::WeightDialog(QWidget *parent) :
     setWindowTitle("Save weight");
 
     hLayout = new QHBoxLayout();
-    QVBoxLayout *buttonLayout = new QVBoxLayout();
+    buttonLayout = new QVBoxLayout();
     qDebug () << "WeightDialog::WeightDialog 2";
     modelReps = new QStandardItemModel(this);
     for (int i = 1; i <= 25; i++)
@@ -105,11 +105,11 @@ void WeightDialog::load(QString name, QString grp, QString currentSet)
 
 void WeightDialog::loadCardio(QString name, QString m, QString s)
 {
-    hLayout->removeWidget(btnReps);
+    buttonLayout->removeWidget(btnReps);
     //btnReps->setEnabled(false);
     btnVar->setText("Distance");
     QList <QString> list;
-    int select;
+
 
     group = "Cardio";
     exName = name;
@@ -195,3 +195,8 @@ void WeightDialog::save()
     qDebug () << "WeightDialog::save 8";
     this->hide();
 }
+
+void WeightDialog::closeEvent(QCloseEvent *event)
+{
+    return event->ignore();
+}
