@@ -24,6 +24,8 @@ private slots:
 private:
     XML *xml;
 
+    void closeEvent(QCloseEvent *event);
+
     QRadioButton *radioEasy;
     QRadioButton *radioOK;
     QRadioButton *radioHard;
@@ -40,6 +42,7 @@ private:
     QMaemo5ListPickSelector *selectorVar;
 
     QHBoxLayout *hLayout;
+    QVBoxLayout *buttonLayout;
 
     QString group;
     QString exName;
